def is_valid(num):
    """
    Checks if the given string is an integer in range <0,9>

    :param:
    num(string) - input string for check

    :return:
    True if string is convertable to integer in correct range, else False
    """
    return num.isdigit() and 0 <= int(num) <= 9


def is_valid_string(string):
    """
    Checks if the given string matches the condition in is_valid(string) method

    :param:
    string(string) - string that is being checked

    :return:
    True if the string matches the condition, else False
    """
    for char in string:
        if not is_valid(char):
            return False

    return True


def process_input(num):
    """
    Return a dot if given number is even and dash if it is odd

    :param:
    num(int) - integer to convert

    :return:
    Returns string dot or dash, depending on integer param
    """
    if num % 2 == 0:
        return "."
    else:
        return "-"


def getKeyByValue(dictionary, curr_word):
    """
    Iterates through the given dictionary and returns the key corresponding to the given string

    :param:
    dictionary(Dictionary) - dictionary where to look for the value
    curr_word(string) - string of dots and dashes, which is being searched for in the dictionary

    :return:
    Corresponding key from the dictionary as string, or None if the value is not found
    """
    for key, val in dictionary.items():
        if val == curr_word:
            return key
    return None


def parse_morse(text):
    """
    Transforms the given string of integers to the output string using Morse code logic
    0 is space, even number is dot, odd number is dash
    Example - string 22220202122021220111 is transformed to HELLO

    :param:
    text(string) - given string of integers to transform

    :return:
    String corresponding to the given string of integers
    """
    result = ""
    morse = {"A": ".-", "B": "-...", "C": "-.-.", "D": "-..", "E": ".",
             "F": "..-.", "G": "--.", "H": "....", "I": "..", "J": ".---",
             "K": "-.-", "L": ".-..", "M": "--", "N": "-.", "O": "---",
             "P": ".--.", "Q": "--.-", "R": ".-.", "S": "...", "T": "-",
             "U": "..-", "V": "...-", "W": ".--", "X": "-..-", "Y": " -. - -", "Z": "--.."}

    curr_word = ""
    for num in text:
        if int(num) == 0:
            result += getKeyByValue(morse, curr_word)
            curr_word = ""
        else:
            curr_word += process_input(int(num))

    result += getKeyByValue(morse, curr_word)

    return result


if __name__ == '__main__':
    morse_input = input("Zadejte vstup pro morseovku: ")
    if is_valid_string(morse_input):
        print("")
        print(parse_morse(morse_input))
    else:
        print("Zadany retezec se nesklada jen z prirozenych cisel od 0 do 9!")

input("STOP")
