# Autor: Martin Riedl
# Datum vytvoření: 1. října 2024
# Program pro generování náhodných čísel a jejich klasifikaci

# Import knihovny pro generování náhodných čísel
import random

# ANSI escape sequences for colors
YELLOW = "\033[93m"
GREEN = "\033[92m"
RED = "\033[91m"
CYAN = "\033[96m"
MAGENTA = "\033[95m"
BLUE = "\033[94m"
RESET = "\033[0m"  # Reset to default color

# Logika programu

# Funkce pro zobrazení výsledku podle rozsahu čísla <0, 100>
def classify_number_100(number):
    if number <= 50:
        return f"{GREEN}Malé číslo{RESET}"
    else:
        return f"{RED}Velké číslo{RESET}"

# Funkce pro zobrazení výsledku podle rozsahu čísla <0, 500>
def classify_number_500(number):
    if number <= 150:
        return f"{GREEN}Malé číslo{RESET}"
    elif 151 <= number <= 350:
        return f"{CYAN}Průměrné číslo{RESET}"
    else:
        return f"{RED}Velké číslo{RESET}"

# Funkce pro generování čísla z intervalu <0, 100> a zobrazení jeho klasifikace
def generate_and_classify_100():
    try:
        number = random.randint(0, 100)
        print(f"{YELLOW}Vygenerované číslo: {number}{RESET}")
        result = classify_number_100(number)
        print(result)
    except Exception as e:
        print(f"{RED}Došlo k chybě při generování čísla: {e}{RESET}")

# Funkce pro generování čísla z intervalu <0, 500> a zobrazení jeho klasifikace
def generate_and_classify_500():
    try:
        number = random.randint(0, 500)
        print(f"{YELLOW}Vygenerované číslo: {number}{RESET}")
        result = classify_number_500(number)
        print(result)
    except Exception as e:
        print(f"{RED}Došlo k chybě při generování čísla: {e}{RESET}")

# Funkce pro zobrazení nápovědy
def show_help():
    print(f"{BLUE}Nápověda k programu pro generování náhodných čísel:{RESET}\n")
    print(f"{CYAN}1. Zvolte volbu 1 pro generování čísla z intervalu <0, 100>.{RESET}")
    print(f"{CYAN}2. Zvolte volbu 2 pro generování čísla z intervalu <0, 500>.{RESET}")
    print(f"{CYAN}3. Zvolte volbu 3 pro ukončení programu.{RESET}")
    print(f"{CYAN}4. Zvolte volbu 4 pro zobrazení této nápovědy.{RESET}\n")
    print(f"{MAGENTA}Klasifikace čísel:{RESET}")
    print(f"{MAGENTA}- Čísla v intervalu <0, 100>: malé číslo (≤ 50), velké číslo (> 50).{RESET}")
    print(f"{MAGENTA}- Čísla v intervalu <0, 500>: malé číslo (≤ 150), průměrné číslo (151–350), velké číslo (> 350).{RESET}")

# Funkce pro výběr akce uživatelem
def get_user_choice():
    print(f"\n{YELLOW}Vyberte akci:{RESET}")
    print(f"{CYAN}1. Generovat číslo z intervalu <0, 100>{RESET}")
    print(f"{CYAN}2. Generovat číslo z intervalu <0, 500>{RESET}")
    print(f"{CYAN}3. Ukončit program{RESET}")
    print(f"{CYAN}4. Zobrazit nápovědu{RESET}")
    
    try:
        return int(input(f"{YELLOW}Zadejte svou volbu (1, 2, 3, 4): {RESET}"))
    except ValueError:
        print(f"{RED}Chyba: zadejte prosím platné číslo.{RESET}")
        return None

# Funkce pro zpracování výběru uživatele
def handle_user_choice(choice):
    if choice == 1:
        generate_and_classify_100()
    elif choice == 2:
        generate_and_classify_500()
    elif choice == 3:
        print(f"{MAGENTA}Ukončuji program.{RESET}")
        return False
    elif choice == 4:
        show_help()
    else:
        print(f"{RED}Neplatná volba, zkuste to znovu.{RESET}")
    return True

# Hlavní funkce, která umožní uživateli volat specifické funkce
def main():
    running = True
    while running:
        choice = get_user_choice()
        if choice is not None:
            running = handle_user_choice(choice)

# Zavolání hlavní funkce
if __name__ == "__main__":
    main()
